[frogr] Updated flicksoup examples to help check things in a better way.



commit 6d92e41a973f0542251ffcf243226bc07d5a61cc
Author: Mario Sanchez Prada <msanchez igalia com>
Date:   Mon Apr 9 01:10:15 2012 +0200

    Updated flicksoup examples to help check things in a better way.
    
    Note: some day I should think about implementing real tests.

 src/examples/example.c |   10 +++++-----
 1 files changed, 5 insertions(+), 5 deletions(-)
---
diff --git a/src/examples/example.c b/src/examples/example.c
index 1d86cb9..1cc7fc7 100644
--- a/src/examples/example.c
+++ b/src/examples/example.c
@@ -96,7 +96,7 @@ upload_cb                               (GObject      *object,
       else if (source_func == photoset_created_cb)
         {
           /* Continue adding the picture to the photoset */
-          g_print ("Creatine a new photoset...\n");
+          g_print ("Adding picture to photoset...\n");
           fsp_session_add_to_photoset_async (session,
                                              uploaded_photo_id,
                                              created_photoset_id,
@@ -104,8 +104,8 @@ upload_cb                               (GObject      *object,
         }
       else if (source_func == get_groups_cb)
         {
-          /* Continue adding the picture to the photoset */
-          g_print ("Creatine a new photoset...\n");
+          /* Continue adding the picture to the group */
+          g_print ("Adding picture to group...\n");
           fsp_session_add_to_group_async (session,
                                           uploaded_photo_id,
                                           first_group_id,
@@ -440,8 +440,8 @@ get_tags_list_cb (GObject *object, GAsyncResult *res, gpointer unused)
       g_print ("Uploading a picture...\n");
       fsp_session_upload_async (session,
                                 test_photo_path,
-                                "title",
-                                "description",
+                                "title with spaces and wÃÃrd characters!",
+                                "description with\nmultiple lines",
                                 "ÃÃÃÃu "
                                 "ÃÃ*+[]{} "
                                 "qwerty "



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]